.. _acknowledging:

************************
Acknowledging ``sammi``
************************

If you use ``sammi`` in your work, we kindly ask you to cite the following reference in you publications:

* |sammi all versions| Andrew Robbertz and Maxine Hartnett, “sammi-cdf”. Zenodo, Feb. 18, 2025. doi: 10.5281/zenodo.14887800.

.. |sammi all versions| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.14887800.svg
    :target: https://doi.org/10.5281/zenodo.14887800
    :alt: DOI

Citing this reference helps to spread awareness of ``sammi``'s capabilities and gives credit to those who have contributed.

You may also like to include the `sammi logo`_ in your presentations. This helps to publicize
``sammi`` to others who might find it helpful in their work.

.. _sammi logo: https://github.com/swxsoc/sammi/blob/f8086f30cd7baf4998d187078edfd6cceb866b04/docs/logo/sammi_logo.png


Other SAMMI publications
========================

The following citations are also relevant to ``sammi`` and show information about its development, use, and capabilities:

* |2024 AGU Robbertz| A. Robbertz, SWxSOC Software Architecture for Science Data Processing. Zenodo, 2024. doi: 10.5281/zenodo.14606063.
* |2024 AGU Hartnett| M. Hartnett, Increasing Open Source Collaboration for Better Scientific Code. Zenodo, 2024. doi: 10.5281/zenodo.14503065.

.. |2024 AGU Robbertz| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.14606063.svg
    :target: https://doi.org/10.5281/zenodo.14606063
    :alt: DOI
.. |2024 AGU Hartnett| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.14503065.svg
    :target: https://doi.org/10.5281/zenodo.14503065
    :alt: DOI
